# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.feature_store.v1.internal.data_source import data_source_service_pb2 as qwak_dot_feature__store_dot_v1_dot_internal_dot_data__source_dot_data__source__service__pb2


class DataSourceServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetDataSourceSourceCodeUploadURL = channel.unary_unary(
                '/qwak.feature.store.management.v1.internal.sources.DataSourceService/GetDataSourceSourceCodeUploadURL',
                request_serializer=qwak_dot_feature__store_dot_v1_dot_internal_dot_data__source_dot_data__source__service__pb2.GetDataSourceSourceCodeUploadRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_v1_dot_internal_dot_data__source_dot_data__source__service__pb2.GetDataSourceSourceCodeUploadResponse.FromString,
                )
        self.GetDataSourceSourceCodeDownloadURL = channel.unary_unary(
                '/qwak.feature.store.management.v1.internal.sources.DataSourceService/GetDataSourceSourceCodeDownloadURL',
                request_serializer=qwak_dot_feature__store_dot_v1_dot_internal_dot_data__source_dot_data__source__service__pb2.GetDataSourceSourceCodeDownloadURLRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_v1_dot_internal_dot_data__source_dot_data__source__service__pb2.GetDataSourceSourceCodeDownloadURLResponse.FromString,
                )


class DataSourceServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetDataSourceSourceCodeUploadURL(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataSourceSourceCodeDownloadURL(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataSourceServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetDataSourceSourceCodeUploadURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataSourceSourceCodeUploadURL,
                    request_deserializer=qwak_dot_feature__store_dot_v1_dot_internal_dot_data__source_dot_data__source__service__pb2.GetDataSourceSourceCodeUploadRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_v1_dot_internal_dot_data__source_dot_data__source__service__pb2.GetDataSourceSourceCodeUploadResponse.SerializeToString,
            ),
            'GetDataSourceSourceCodeDownloadURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataSourceSourceCodeDownloadURL,
                    request_deserializer=qwak_dot_feature__store_dot_v1_dot_internal_dot_data__source_dot_data__source__service__pb2.GetDataSourceSourceCodeDownloadURLRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_v1_dot_internal_dot_data__source_dot_data__source__service__pb2.GetDataSourceSourceCodeDownloadURLResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.feature.store.management.v1.internal.sources.DataSourceService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataSourceService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetDataSourceSourceCodeUploadURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.management.v1.internal.sources.DataSourceService/GetDataSourceSourceCodeUploadURL',
            qwak_dot_feature__store_dot_v1_dot_internal_dot_data__source_dot_data__source__service__pb2.GetDataSourceSourceCodeUploadRequest.SerializeToString,
            qwak_dot_feature__store_dot_v1_dot_internal_dot_data__source_dot_data__source__service__pb2.GetDataSourceSourceCodeUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataSourceSourceCodeDownloadURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.management.v1.internal.sources.DataSourceService/GetDataSourceSourceCodeDownloadURL',
            qwak_dot_feature__store_dot_v1_dot_internal_dot_data__source_dot_data__source__service__pb2.GetDataSourceSourceCodeDownloadURLRequest.SerializeToString,
            qwak_dot_feature__store_dot_v1_dot_internal_dot_data__source_dot_data__source__service__pb2.GetDataSourceSourceCodeDownloadURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
