"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import qwak.user_application.common.v0.resources_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _BatchJobEventTypeMessage:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BatchJobEventTypeMessageEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BatchJobEventTypeMessage.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNDEFINED_BATCH_JOB_EVENT: _BatchJobEventTypeMessage.ValueType  # 0
    BATCH_JOB_COMMITTED: _BatchJobEventTypeMessage.ValueType  # 1
    BATCH_JOB_PREPARED: _BatchJobEventTypeMessage.ValueType  # 7
    BATCH_JOB_TASKS_CREATED: _BatchJobEventTypeMessage.ValueType  # 2
    BATCH_JOB_CANCELLED: _BatchJobEventTypeMessage.ValueType  # 3
    BATCH_JOB_CLEANUP: _BatchJobEventTypeMessage.ValueType  # 4
    BATCH_JOB_CHECK_FINISHED: _BatchJobEventTypeMessage.ValueType  # 5
    BATCH_JOB_CHECK_TIMEOUT: _BatchJobEventTypeMessage.ValueType  # 6

class BatchJobEventTypeMessage(_BatchJobEventTypeMessage, metaclass=_BatchJobEventTypeMessageEnumTypeWrapper): ...

UNDEFINED_BATCH_JOB_EVENT: BatchJobEventTypeMessage.ValueType  # 0
BATCH_JOB_COMMITTED: BatchJobEventTypeMessage.ValueType  # 1
BATCH_JOB_PREPARED: BatchJobEventTypeMessage.ValueType  # 7
BATCH_JOB_TASKS_CREATED: BatchJobEventTypeMessage.ValueType  # 2
BATCH_JOB_CANCELLED: BatchJobEventTypeMessage.ValueType  # 3
BATCH_JOB_CLEANUP: BatchJobEventTypeMessage.ValueType  # 4
BATCH_JOB_CHECK_FINISHED: BatchJobEventTypeMessage.ValueType  # 5
BATCH_JOB_CHECK_TIMEOUT: BatchJobEventTypeMessage.ValueType  # 6
global___BatchJobEventTypeMessage = BatchJobEventTypeMessage

class _BatchTaskEventTypeMessage:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BatchTaskEventTypeMessageEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BatchTaskEventTypeMessage.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNDEFINED_BATCH_TASK_EVENT: _BatchTaskEventTypeMessage.ValueType  # 0
    BATCH_TASK_RUNNING: _BatchTaskEventTypeMessage.ValueType  # 1
    BATCH_TASK_FINISHED: _BatchTaskEventTypeMessage.ValueType  # 2
    BATCH_TASK_FAILED: _BatchTaskEventTypeMessage.ValueType  # 3
    BATCH_TASK_CHECK_STATUS: _BatchTaskEventTypeMessage.ValueType  # 4
    BATCH_TASK_START: _BatchTaskEventTypeMessage.ValueType  # 5
    BATCH_TASK_CLEANUP: _BatchTaskEventTypeMessage.ValueType  # 6

class BatchTaskEventTypeMessage(_BatchTaskEventTypeMessage, metaclass=_BatchTaskEventTypeMessageEnumTypeWrapper): ...

UNDEFINED_BATCH_TASK_EVENT: BatchTaskEventTypeMessage.ValueType  # 0
BATCH_TASK_RUNNING: BatchTaskEventTypeMessage.ValueType  # 1
BATCH_TASK_FINISHED: BatchTaskEventTypeMessage.ValueType  # 2
BATCH_TASK_FAILED: BatchTaskEventTypeMessage.ValueType  # 3
BATCH_TASK_CHECK_STATUS: BatchTaskEventTypeMessage.ValueType  # 4
BATCH_TASK_START: BatchTaskEventTypeMessage.ValueType  # 5
BATCH_TASK_CLEANUP: BatchTaskEventTypeMessage.ValueType  # 6
global___BatchTaskEventTypeMessage = BatchTaskEventTypeMessage

class _WarmupEventTypeMessage:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WarmupEventTypeMessageEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WarmupEventTypeMessage.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNDEFINED_WARMUP_JOB_EVENT: _WarmupEventTypeMessage.ValueType  # 0
    WARMUP_JOB_COMMITTED: _WarmupEventTypeMessage.ValueType  # 1
    WARMUP_CANCEL: _WarmupEventTypeMessage.ValueType  # 2

class WarmupEventTypeMessage(_WarmupEventTypeMessage, metaclass=_WarmupEventTypeMessageEnumTypeWrapper): ...

UNDEFINED_WARMUP_JOB_EVENT: WarmupEventTypeMessage.ValueType  # 0
WARMUP_JOB_COMMITTED: WarmupEventTypeMessage.ValueType  # 1
WARMUP_CANCEL: WarmupEventTypeMessage.ValueType  # 2
global___WarmupEventTypeMessage = WarmupEventTypeMessage

class _MemoryUnit:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MemoryUnitEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MemoryUnit.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _MemoryUnit.ValueType  # 0
    MIB: _MemoryUnit.ValueType  # 1
    GIB: _MemoryUnit.ValueType  # 2

class MemoryUnit(_MemoryUnit, metaclass=_MemoryUnitEnumTypeWrapper): ...

UNKNOWN: MemoryUnit.ValueType  # 0
MIB: MemoryUnit.ValueType  # 1
GIB: MemoryUnit.ValueType  # 2
global___MemoryUnit = MemoryUnit

class _TaskFailureReasonCode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TaskFailureReasonCodeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TaskFailureReasonCode.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TASK_FAILURE_REASON_CODE_FAILURE_CODE_UNSPECIFIED: _TaskFailureReasonCode.ValueType  # 0
    TASK_FAILURE_REASON_CODE_NO_REPLICA_SETS_PODS_FOUND_FAILURE_CODE: _TaskFailureReasonCode.ValueType  # 1
    TASK_FAILURE_REASON_CODE_MODEL_CONTAINER_NOT_FOUND_FAILURE_CODE: _TaskFailureReasonCode.ValueType  # 2
    TASK_FAILURE_REASON_CODE_UNSCHEDULABLE_FAILURE_CODE: _TaskFailureReasonCode.ValueType  # 3
    TASK_FAILURE_REASON_CODE_DOCKER_IMAGE_NOT_FOUND_FAILURE_CODE: _TaskFailureReasonCode.ValueType  # 4
    TASK_FAILURE_REASON_CODE_MEMORY_LIMIT_EXCEEDED_FAILURE_CODE: _TaskFailureReasonCode.ValueType  # 5
    TASK_FAILURE_REASON_CODE_CRASH_LOOP_FAILURE_CODE: _TaskFailureReasonCode.ValueType  # 6
    TASK_FAILURE_REASON_CODE_CONTAINER_FAIL_TO_LOAD_FOR_UNKNOWN_REASON: _TaskFailureReasonCode.ValueType  # 7
    TASK_FAILURE_REASON_CODE_UNKNOWN_REASON: _TaskFailureReasonCode.ValueType  # 8
    TASK_FAILURE_REASON_CODE_DOCKER_IMAGE_GETS_THROTTLING_BY_CLOUD_PROVIDER_FAILURE_CODE: _TaskFailureReasonCode.ValueType  # 9

class TaskFailureReasonCode(_TaskFailureReasonCode, metaclass=_TaskFailureReasonCodeEnumTypeWrapper): ...

TASK_FAILURE_REASON_CODE_FAILURE_CODE_UNSPECIFIED: TaskFailureReasonCode.ValueType  # 0
TASK_FAILURE_REASON_CODE_NO_REPLICA_SETS_PODS_FOUND_FAILURE_CODE: TaskFailureReasonCode.ValueType  # 1
TASK_FAILURE_REASON_CODE_MODEL_CONTAINER_NOT_FOUND_FAILURE_CODE: TaskFailureReasonCode.ValueType  # 2
TASK_FAILURE_REASON_CODE_UNSCHEDULABLE_FAILURE_CODE: TaskFailureReasonCode.ValueType  # 3
TASK_FAILURE_REASON_CODE_DOCKER_IMAGE_NOT_FOUND_FAILURE_CODE: TaskFailureReasonCode.ValueType  # 4
TASK_FAILURE_REASON_CODE_MEMORY_LIMIT_EXCEEDED_FAILURE_CODE: TaskFailureReasonCode.ValueType  # 5
TASK_FAILURE_REASON_CODE_CRASH_LOOP_FAILURE_CODE: TaskFailureReasonCode.ValueType  # 6
TASK_FAILURE_REASON_CODE_CONTAINER_FAIL_TO_LOAD_FOR_UNKNOWN_REASON: TaskFailureReasonCode.ValueType  # 7
TASK_FAILURE_REASON_CODE_UNKNOWN_REASON: TaskFailureReasonCode.ValueType  # 8
TASK_FAILURE_REASON_CODE_DOCKER_IMAGE_GETS_THROTTLING_BY_CLOUD_PROVIDER_FAILURE_CODE: TaskFailureReasonCode.ValueType  # 9
global___TaskFailureReasonCode = TaskFailureReasonCode

class BatchJobEventMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BATCH_JOB_EVENT_TYPE_FIELD_NUMBER: builtins.int
    BATCH_JOB_ID_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    DELAY_FIELD_NUMBER: builtins.int
    FAILURES_FIELD_NUMBER: builtins.int
    batch_job_event_type: global___BatchJobEventTypeMessage.ValueType
    batch_job_id: builtins.str
    message: builtins.str
    delay: builtins.int
    failures: builtins.int
    def __init__(
        self,
        *,
        batch_job_event_type: global___BatchJobEventTypeMessage.ValueType = ...,
        batch_job_id: builtins.str = ...,
        message: builtins.str = ...,
        delay: builtins.int = ...,
        failures: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_job_event_type", b"batch_job_event_type", "batch_job_id", b"batch_job_id", "delay", b"delay", "failures", b"failures", "message", b"message"]) -> None: ...

global___BatchJobEventMessage = BatchJobEventMessage

class BatchTaskEventMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BATCH_TASK_EVENT_TYPE_FIELD_NUMBER: builtins.int
    BATCH_JOB_ID_FIELD_NUMBER: builtins.int
    BATCH_TASK_ID_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    DELAY_FIELD_NUMBER: builtins.int
    FAILURES_FIELD_NUMBER: builtins.int
    BATCH_TASK_FAILURE_REASON_FIELD_NUMBER: builtins.int
    batch_task_event_type: global___BatchTaskEventTypeMessage.ValueType
    batch_job_id: builtins.str
    batch_task_id: builtins.str
    message: builtins.str
    delay: builtins.int
    failures: builtins.int
    @property
    def batch_task_failure_reason(self) -> global___TaskFailureReason: ...
    def __init__(
        self,
        *,
        batch_task_event_type: global___BatchTaskEventTypeMessage.ValueType = ...,
        batch_job_id: builtins.str = ...,
        batch_task_id: builtins.str = ...,
        message: builtins.str = ...,
        delay: builtins.int = ...,
        failures: builtins.int = ...,
        batch_task_failure_reason: global___TaskFailureReason | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["batch_task_failure_reason", b"batch_task_failure_reason"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_job_id", b"batch_job_id", "batch_task_event_type", b"batch_task_event_type", "batch_task_failure_reason", b"batch_task_failure_reason", "batch_task_id", b"batch_task_id", "delay", b"delay", "failures", b"failures", "message", b"message"]) -> None: ...

global___BatchTaskEventMessage = BatchTaskEventMessage

class WarmupEventMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WARMUP_JOB_EVENT_TYPE_FIELD_NUMBER: builtins.int
    DELAY_FIELD_NUMBER: builtins.int
    FAILURES_FIELD_NUMBER: builtins.int
    WARMUP_SIZE_FIELD_NUMBER: builtins.int
    MODEL_IDENTIFIER_FIELD_NUMBER: builtins.int
    warmup_job_event_type: global___WarmupEventTypeMessage.ValueType
    delay: builtins.int
    failures: builtins.int
    @property
    def warmup_size(self) -> global___WarmupSize: ...
    @property
    def model_identifier(self) -> global___ModelIdentifierMessage: ...
    def __init__(
        self,
        *,
        warmup_job_event_type: global___WarmupEventTypeMessage.ValueType = ...,
        delay: builtins.int = ...,
        failures: builtins.int = ...,
        warmup_size: global___WarmupSize | None = ...,
        model_identifier: global___ModelIdentifierMessage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model_identifier", b"model_identifier", "warmup_size", b"warmup_size"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delay", b"delay", "failures", b"failures", "model_identifier", b"model_identifier", "warmup_job_event_type", b"warmup_job_event_type", "warmup_size", b"warmup_size"]) -> None: ...

global___WarmupEventMessage = WarmupEventMessage

class WarmupSize(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CPU_FIELD_NUMBER: builtins.int
    MEMORY_AMOUNT_FIELD_NUMBER: builtins.int
    MEMORY_UNIT_FIELD_NUMBER: builtins.int
    NUM_OF_PODS_FIELD_NUMBER: builtins.int
    TIMEOUT_SECONDS_FIELD_NUMBER: builtins.int
    GPU_RESOURCES_FIELD_NUMBER: builtins.int
    POD_COMPUTE_RESOURCES_FIELD_NUMBER: builtins.int
    cpu: builtins.float
    memory_amount: builtins.int
    memory_unit: global___MemoryUnit.ValueType
    num_of_pods: builtins.int
    timeout_seconds: builtins.int
    """The timeout for the warmup"""
    @property
    def gpu_resources(self) -> qwak.user_application.common.v0.resources_pb2.GpuResources:
        """Optional GPU resources for batch"""
    @property
    def pod_compute_resources(self) -> qwak.user_application.common.v0.resources_pb2.PodComputeResources: ...
    def __init__(
        self,
        *,
        cpu: builtins.float = ...,
        memory_amount: builtins.int = ...,
        memory_unit: global___MemoryUnit.ValueType = ...,
        num_of_pods: builtins.int = ...,
        timeout_seconds: builtins.int = ...,
        gpu_resources: qwak.user_application.common.v0.resources_pb2.GpuResources | None = ...,
        pod_compute_resources: qwak.user_application.common.v0.resources_pb2.PodComputeResources | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gpu_resources", b"gpu_resources", "pod_compute_resources", b"pod_compute_resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cpu", b"cpu", "gpu_resources", b"gpu_resources", "memory_amount", b"memory_amount", "memory_unit", b"memory_unit", "num_of_pods", b"num_of_pods", "pod_compute_resources", b"pod_compute_resources", "timeout_seconds", b"timeout_seconds"]) -> None: ...

global___WarmupSize = WarmupSize

class ModelIdentifierMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    BRANCH_ID_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    branch_id: builtins.str
    build_id: builtins.str
    user_id: builtins.str
    environment_id: builtins.str
    account_id: builtins.str
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        branch_id: builtins.str = ...,
        build_id: builtins.str = ...,
        user_id: builtins.str = ...,
        environment_id: builtins.str = ...,
        account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "branch_id", b"branch_id", "build_id", b"build_id", "environment_id", b"environment_id", "model_id", b"model_id", "user_id", b"user_id"]) -> None: ...

global___ModelIdentifierMessage = ModelIdentifierMessage

class TaskFailureReason(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FAILURE_REASON_CODE_FIELD_NUMBER: builtins.int
    TASK_FAILURE_REASON_DETAILS_FIELD_NUMBER: builtins.int
    task_failure_reason_code: global___TaskFailureReasonCode.ValueType
    task_failure_reason_details: builtins.str
    def __init__(
        self,
        *,
        task_failure_reason_code: global___TaskFailureReasonCode.ValueType = ...,
        task_failure_reason_details: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["task_failure_reason_code", b"task_failure_reason_code", "task_failure_reason_details", b"task_failure_reason_details"]) -> None: ...

global___TaskFailureReason = TaskFailureReason
