"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.monitoring.v0.alerting_channel_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ListAlertingChannelsForEdgeClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SYNC_CHANNELS_SINCE_FIELD_NUMBER: builtins.int
    @property
    def sync_channels_since(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time the channels should be synced from"""
    def __init__(
        self,
        *,
        sync_channels_since: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["sync_channels_since", b"sync_channels_since"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["sync_channels_since", b"sync_channels_since"]) -> None: ...

global___ListAlertingChannelsForEdgeClusterRequest = ListAlertingChannelsForEdgeClusterRequest

class ListAlertingChannelsForEdgeClusterResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SYNC_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def sync_response(self) -> qwak.monitoring.v0.alerting_channel_pb2.SyncResponse:
        """what channels to sync or an indicator for up-to-date"""
    def __init__(
        self,
        *,
        sync_response: qwak.monitoring.v0.alerting_channel_pb2.SyncResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["sync_response", b"sync_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["sync_response", b"sync_response"]) -> None: ...

global___ListAlertingChannelsForEdgeClusterResponse = ListAlertingChannelsForEdgeClusterResponse

class ListAlertingChannelsForCoreClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SYNC_CHANNELS_SINCE_FIELD_NUMBER: builtins.int
    @property
    def sync_channels_since(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time the channels should be synced from"""
    def __init__(
        self,
        *,
        sync_channels_since: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["sync_channels_since", b"sync_channels_since"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["sync_channels_since", b"sync_channels_since"]) -> None: ...

global___ListAlertingChannelsForCoreClusterRequest = ListAlertingChannelsForCoreClusterRequest

class ListAlertingChannelsForCoreClusterResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SYNC_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def sync_response(self) -> qwak.monitoring.v0.alerting_channel_pb2.SyncResponse:
        """what channels to sync or an indicator for up-to-date"""
    def __init__(
        self,
        *,
        sync_response: qwak.monitoring.v0.alerting_channel_pb2.SyncResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["sync_response", b"sync_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["sync_response", b"sync_response"]) -> None: ...

global___ListAlertingChannelsForCoreClusterResponse = ListAlertingChannelsForCoreClusterResponse
