# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: jfml/hosting_gateway/v1/build_upload_url.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.jfml/hosting_gateway/v1/build_upload_url.proto\x12\x17jfml.hosting_gateway.v1\"\xd3\x01\n\x18\x42uildUploadUrlParameters\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\x12\x11\n\ttag_value\x18\x03 \x01(\t\x12\x41\n\rartifact_type\x18\x04 \x01(\x0e\x32*.jfml.hosting_gateway.v1.BuildArtifactType\x12$\n\x1ause_cloud_provider_storage\x18\x05 \x01(\x08H\x00\x42\x17\n\x15\x63loud_provider_option*v\n\x11\x42uildArtifactType\x12\x19\n\x15INVALID_ARTIFACT_TYPE\x10\x00\x12\x16\n\x12\x44\x41TA_ARTIFACT_TYPE\x10\x01\x12\x16\n\x12\x46ILE_ARTIFACT_TYPE\x10\x02\x12\x16\n\x12\x43ODE_ARTIFACT_TYPE\x10\x03\x42\'\n#com.jfrog.ml.hosting_gateway.api.v1P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'jfml.hosting_gateway.v1.build_upload_url_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.jfrog.ml.hosting_gateway.api.v1P\001'
  _globals['_BUILDARTIFACTTYPE']._serialized_start=289
  _globals['_BUILDARTIFACTTYPE']._serialized_end=407
  _globals['_BUILDUPLOADURLPARAMETERS']._serialized_start=76
  _globals['_BUILDUPLOADURLPARAMETERS']._serialized_end=287
# @@protoc_insertion_point(module_scope)
