# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/account/v1/account.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.administration.account.v1 import preferences_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_preferences__pb2
from _qwak_proto.qwak.administration.account.v1 import terms_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_terms__pb2
from _qwak_proto.qwak.administration.account.v1 import jfrog_tenant_details_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_jfrog__tenant__details__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,qwak/administration/account/v1/account.proto\x12\x1eqwak.administration.account.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x30qwak/administration/account/v1/preferences.proto\x1a*qwak/administration/account/v1/terms.proto\x1a\x39qwak/administration/account/v1/jfrog_tenant_details.proto\"\xc9\x04\n\x07\x41\x63\x63ount\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x45\n\x06status\x18\x04 \x01(\x0e\x32\x35.qwak.administration.account.v1.AccountActivityStatus\x12\x44\n\x0bpreferences\x18\x07 \x01(\x0b\x32/.qwak.administration.account.AccountPreferences\x12\x1e\n\x16\x64\x65\x66\x61ult_environment_id\x18\x08 \x01(\t\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10last_modified_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x04type\x18\t \x01(\x0e\x32+.qwak.administration.account.v1.AccountType\x12\x39\n\x04tier\x18\n \x01(\x0e\x32+.qwak.administration.account.v1.AccountTier\x12I\n\x0e\x61\x63\x63\x65pted_terms\x18\x0b \x01(\x0b\x32\x31.qwak.administration.account.AccountAcceptedTerms\x12P\n\x14jfrog_tenant_details\x18\x0c \x01(\x0b\x32\x32.qwak.administration.account.v1.JfrogTenantDetails\"c\n\x11ListAccountFilter\x12N\n\x0f\x61\x63tivity_status\x18\x01 \x01(\x0e\x32\x35.qwak.administration.account.v1.AccountActivityStatus\"_\n\x12\x41utoBindingAccount\x12\n\n\x02id\x18\x01 \x01(\t\x12=\n\x04rule\x18\x02 \x01(\x0b\x32/.qwak.administration.account.v1.AutoBindingRule\")\n\x0f\x41utoBindingRule\x12\x16\n\x0e\x65mail_hostname\x18\x01 \x01(\t\"\xb1\x02\n\x0c\x41\x63\x63ountBrief\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x19\n\x0fjfrog_tenant_id\x18\x02 \x01(\tH\x00\x12\x1b\n\x0f\x65nvironment_ids\x18\x03 \x03(\tB\x02\x18\x01\x12\x16\n\x0e\x64\x65\x66\x61ult_env_id\x18\x04 \x01(\t\x12L\n\x12\x65nvironment_briefs\x18\x05 \x03(\x0b\x32\x30.qwak.administration.account.v1.EnvironmentBrief\x12\x41\n\x0bjpd_details\x18\x06 \x01(\x0b\x32*.qwak.administration.account.v1.JPDDetailsH\x01\x42\x14\n\x12optional_tenant_idB\x16\n\x14optional_jpd_details\"B\n\x10\x45nvironmentBrief\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\x12\x16\n\x0estorage_bucket\x18\x02 \x01(\t*k\n\x15\x41\x63\x63ountActivityStatus\x12\x1a\n\x16\x41\x43\x43OUNT_STATUS_INVALID\x10\x00\x12\x19\n\x15\x41\x43\x43OUNT_STATUS_ACTIVE\x10\x01\x12\x1b\n\x17\x41\x43\x43OUNT_STATUS_DISABLED\x10\x02*=\n\x0b\x41\x63\x63ountType\x12\x18\n\x14\x41\x43\x43OUNT_TYPE_INVALID\x10\x00\x12\n\n\x06HYBRID\x10\x01\x12\x08\n\x04SAAS\x10\x02*L\n\x0b\x41\x63\x63ountTier\x12\x18\n\x14\x41\x43\x43OUNT_TIER_INVALID\x10\x00\x12\x08\n\x04\x46REE\x10\x01\x12\r\n\tVALIDATED\x10\x02\x12\n\n\x06PAYING\x10\x03\x42\xb4\x01\n)com.qwak.ai.administration.api.account.v1P\x01Z\x84\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/account/v1;account_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.account.v1.account_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.qwak.ai.administration.api.account.v1P\001Z\204\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/account/v1;account_v0'
  _ACCOUNTBRIEF.fields_by_name['environment_ids']._options = None
  _ACCOUNTBRIEF.fields_by_name['environment_ids']._serialized_options = b'\030\001'
  _globals['_ACCOUNTACTIVITYSTATUS']._serialized_start=1471
  _globals['_ACCOUNTACTIVITYSTATUS']._serialized_end=1578
  _globals['_ACCOUNTTYPE']._serialized_start=1580
  _globals['_ACCOUNTTYPE']._serialized_end=1641
  _globals['_ACCOUNTTIER']._serialized_start=1643
  _globals['_ACCOUNTTIER']._serialized_end=1719
  _globals['_ACCOUNT']._serialized_start=267
  _globals['_ACCOUNT']._serialized_end=852
  _globals['_LISTACCOUNTFILTER']._serialized_start=854
  _globals['_LISTACCOUNTFILTER']._serialized_end=953
  _globals['_AUTOBINDINGACCOUNT']._serialized_start=955
  _globals['_AUTOBINDINGACCOUNT']._serialized_end=1050
  _globals['_AUTOBINDINGRULE']._serialized_start=1052
  _globals['_AUTOBINDINGRULE']._serialized_end=1093
  _globals['_ACCOUNTBRIEF']._serialized_start=1096
  _globals['_ACCOUNTBRIEF']._serialized_end=1401
  _globals['_ENVIRONMENTBRIEF']._serialized_start=1403
  _globals['_ENVIRONMENTBRIEF']._serialized_end=1469
# @@protoc_insertion_point(module_scope)
