# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/deployment/deployment.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from _qwak_proto.qwak.audience.v1 import audience_pb2 as qwak_dot_audience_dot_v1_dot_audience__pb2
from _qwak_proto.qwak.auto_scaling.v1 import auto_scaling_pb2 as qwak_dot_auto__scaling_dot_v1_dot_auto__scaling__pb2
from _qwak_proto.qwak.user_application.common.v0 import resources_pb2 as qwak_dot_user__application_dot_common_dot_v0_dot_resources__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n qwak/deployment/deployment.proto\x12\x1aqwak.deployment.management\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fqwak/audience/v1/audience.proto\x1a\'qwak/auto_scaling/v1/auto_scaling.proto\x1a/qwak/user_application/common/v0/resources.proto\"(\n\x1aQwakModeRegistryIdentifier\x12\n\n\x02id\x18\x01 \x01(\t\"\x9e\x01\n\x0eHostingService\x12>\n\tsagemaker\x18\x01 \x01(\x0b\x32%.qwak.deployment.management.SageMakerB\x02\x18\x01H\x00\x12\x45\n\x0fkube_deployment\x18\x02 \x01(\x0b\x32*.qwak.deployment.management.KubeDeploymentH\x00\x42\x05\n\x03val\"\xff\x03\n\x0eKubeDeployment\x12\x15\n\tpod_count\x18\x04 \x01(\x05\x42\x02\x18\x01\x12\x43\n\x0f\x64\x65ployment_size\x18\x05 \x01(\x0b\x32*.qwak.deployment.management.DeploymentSize\x12Z\n\x1b\x61\x64vanced_deployment_options\x18\x06 \x01(\x0b\x32\x35.qwak.deployment.management.AdvancedDeploymentOptions\x12L\n\x14kube_deployment_type\x18\x07 \x01(\x0e\x32..qwak.deployment.management.KubeDeploymentType\x12\x45\n\x10serving_strategy\x18\t \x01(\x0b\x32+.qwak.deployment.management.ServingStrategy\x12\x63\n\x15\x65nvironment_variables\x18\n \x03(\x0b\x32\x44.qwak.deployment.management.KubeDeployment.EnvironmentVariablesEntry\x1a;\n\x19\x45nvironmentVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe8\x01\n\x0fServingStrategy\x12\x45\n\x0frealtime_config\x18\x01 \x01(\x0b\x32*.qwak.deployment.management.RealTimeConfigH\x00\x12\x41\n\rstream_config\x18\x02 \x01(\x0b\x32(.qwak.deployment.management.StreamConfigH\x00\x12?\n\x0c\x62\x61tch_config\x18\x03 \x01(\x0b\x32\'.qwak.deployment.management.BatchConfigH\x00\x42\n\n\x08Strategy\"\x99\x01\n\x0eRealTimeConfig\x12\x41\n\x0etraffic_config\x18\x01 \x01(\x0b\x32).qwak.deployment.management.TrafficConfig\x12\x44\n\x13\x61uto_scaling_config\x18\x02 \x01(\x0b\x32\'.qwak.auto_scaling.v1.AutoScalingConfig\"\xfd\x01\n\rTrafficConfig\x12\x1f\n\x17selected_variation_name\x18\x01 \x01(\t\x12=\n\nvariations\x18\x02 \x03(\x0b\x32%.qwak.deployment.management.VariationB\x02\x18\x01\x12\x46\n\x17\x61udience_routes_entries\x18\x03 \x03(\x0b\x32%.qwak.audience.v1.AudienceRoutesEntry\x12\x1a\n\x12\x66\x61llback_variation\x18\x04 \x01(\t\x12(\n selected_variation_protect_state\x18\x05 \x01(\x08\"F\n\x0cStreamConfig\x12\x36\n\x05kafka\x18\x01 \x01(\x0b\x32\'.qwak.deployment.management.KafkaConfig\"\r\n\x0b\x42\x61tchConfig\"\xaf\x05\n\x0bKafkaConfig\x12\x42\n\x08\x63onsumer\x18\x01 \x01(\x0b\x32\x30.qwak.deployment.management.KafkaConfig.Consumer\x12\x42\n\x08producer\x18\x02 \x01(\x0b\x32\x30.qwak.deployment.management.KafkaConfig.Producer\x12\x0f\n\x07workers\x18\x03 \x01(\x05\x1a\x99\x02\n\x08\x43onsumer\x12\x18\n\x10\x62ootstrap_server\x18\x01 \x03(\t\x12\r\n\x05topic\x18\x02 \x01(\t\x12\r\n\x05group\x18\x03 \x01(\t\x12\x0f\n\x07timeout\x18\x04 \x01(\x05\x12Y\n\x10\x61uto_offset_type\x18\x05 \x01(\x0e\x32?.qwak.deployment.management.KafkaConfig.Consumer.AutoOffSetType\x12\x16\n\x0emax_batch_size\x18\x06 \x01(\x05\x12\x18\n\x10max_poll_latency\x18\x07 \x01(\x01\"7\n\x0e\x41utoOffSetType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08\x45\x41RLIEST\x10\x01\x12\n\n\x06LATEST\x10\x02\x1a\xea\x01\n\x08Producer\x12\x18\n\x10\x62ootstrap_server\x18\x01 \x03(\t\x12\r\n\x05topic\x18\x02 \x01(\t\x12Z\n\x10\x63ompression_type\x18\x03 \x01(\x0e\x32@.qwak.deployment.management.KafkaConfig.Producer.CompressionType\"Y\n\x0f\x43ompressionType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x10\n\x0cUNCOMPRESSED\x10\x01\x12\x08\n\x04GZIP\x10\x02\x12\n\n\x06SNAPPY\x10\x03\x12\x07\n\x03LZ4\x10\x04\x12\x08\n\x04ZSTD\x10\x05\":\n\tSageMaker\x12\x16\n\x0einstance_count\x18\x04 \x01(\x05\x12\x15\n\rinstance_type\x18\x05 \x01(\t\"\xc2\x02\n\x0e\x44\x65ploymentSize\x12\x16\n\x0enumber_of_pods\x18\x01 \x01(\x05\x12\x0f\n\x03\x63pu\x18\x02 \x01(\x02\x42\x02\x18\x01\x12\x19\n\rmemory_amount\x18\x03 \x01(\x05\x42\x02\x18\x01\x12@\n\x0cmemory_units\x18\x04 \x01(\x0e\x32&.qwak.deployment.management.MemoryUnitB\x02\x18\x01\x12H\n\rgpu_resources\x18\x05 \x01(\x0b\x32-.qwak.user_application.common.v0.GpuResourcesB\x02\x18\x01\x12`\n\x1c\x63lient_pod_compute_resources\x18\x06 \x01(\x0b\x32:.qwak.user_application.common.v0.ClientPodComputeResources\"Y\n\x0cGpuResources\x12\x35\n\x08gpu_type\x18\x01 \x01(\x0e\x32#.qwak.deployment.management.GpuType\x12\x12\n\ngpu_amount\x18\x02 \x01(\x05\"\xb5\x02\n\x19\x41\x64vancedDeploymentOptions\x12%\n\x1dnumber_of_http_server_workers\x18\x01 \x01(\x05\x12\x1f\n\x17http_request_timeout_ms\x18\x02 \x01(\x05\x12/\n\x0b\x64\x61\x65mon_mode\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1b\n\x13\x63ustom_iam_role_arn\x18\x04 \x01(\t\x12\x16\n\x0emax_batch_size\x18\x05 \x01(\x05\x12(\n deployment_process_timeout_limit\x18\x06 \x01(\x05\x12\x17\n\x0fpurchase_option\x18\x07 \x01(\t\x12\'\n\x1fservice_account_key_secret_name\x18\x08 \x01(\t\"\xb9\n\n\x11\x44\x65ploymentDetails\x12\x31\n\rlast_deployed\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\x08\x62uild_id\x18\x02 \x01(\tH\x00\x12`\n\x1eqwak_model_registry_identifier\x18\x1b \x01(\x0b\x32\x36.qwak.deployment.management.QwakModeRegistryIdentifierH\x00\x12\x16\n\x0enumber_of_pods\x18\x03 \x01(\x05\x12\x14\n\x0c\x63pu_fraction\x18\x04 \x01(\x02\x12\x15\n\rmemory_amount\x18\x05 \x01(\x05\x12<\n\x0cmemory_units\x18\x06 \x01(\x0e\x32&.qwak.deployment.management.MemoryUnit\x12\x19\n\x11number_of_workers\x18\x07 \x01(\x05\x12\x1f\n\x17http_request_timeout_ms\x18\x08 \x01(\x05\x12L\n\x14kube_deployment_type\x18\t \x01(\x0e\x32..qwak.deployment.management.KubeDeploymentType\x12\x45\n\x10serving_strategy\x18\n \x01(\x0b\x32+.qwak.deployment.management.ServingStrategy\x12\x38\n\tvariation\x18\x0b \x01(\x0b\x32%.qwak.deployment.management.Variation\x12\x1b\n\x13\x63ustom_iam_role_arn\x18\x0c \x01(\t\x12\x16\n\x0emax_batch_size\x18\r \x01(\x05\x12:\n\x08gpu_type\x18\x0e \x01(\x0e\x32(.qwak.user_application.common.v0.GpuType\x12\x12\n\ngpu_amount\x18\x0f \x01(\x05\x12\x16\n\x0e\x65nvironment_id\x18\x10 \x01(\t\x12\x1a\n\x12\x61vailable_replicas\x18\x11 \x01(\x05\x12/\n\x0b\x64\x61\x65mon_mode\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12(\n deployment_process_timeout_limit\x18\x13 \x01(\x05\x12\x17\n\x0fpurchase_option\x18\x14 \x01(\t\x12\x66\n\x15\x65nvironment_variables\x18\x15 \x03(\x0b\x32G.qwak.deployment.management.DeploymentDetails.EnvironmentVariablesEntry\x12\x35\n\x11undeployment_time\x18\x16 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x41\n\x06status\x18\x17 \x01(\x0e\x32\x31.qwak.deployment.management.ModelDeploymentStatus\x12\x15\n\rdeployment_id\x18\x18 \x01(\t\x12M\n\x0f\x66\x61ilure_details\x18\x19 \x01(\x0b\x32\x34.qwak.deployment.management.DeploymentFailureDetails\x12\'\n\x1fservice_account_key_secret_name\x18\x1a \x01(\t\x1a;\n\x19\x45nvironmentVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x12\n\x10image_identifier\"3\n\x18\x44\x65ploymentFailureDetails\x12\x17\n\x0f\x66\x61ilure_message\x18\x01 \x01(\t\"\xb9\x01\n\x19RuntimeDeploymentSettings\x12Y\n\x11root_logger_level\x18\x01 \x01(\x0e\x32>.qwak.deployment.management.RuntimeDeploymentSettings.LogLevel\"A\n\x08LogLevel\x12\x0b\n\x07NOT_SET\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x12\x08\n\x04WARN\x10\x02\x12\x08\n\x04INFO\x10\x03\x12\t\n\x05\x44\x45\x42UG\x10\x04\"\xe6\x03\n\x0f\x44\x65ploymentBrief\x12\x12\n\x08\x62uild_id\x18\x01 \x01(\tH\x00\x12`\n\x1eqwak_model_registry_identifier\x18\x0c \x01(\x0b\x32\x36.qwak.deployment.management.QwakModeRegistryIdentifierH\x00\x12\x41\n\x06status\x18\x02 \x01(\x0e\x32\x31.qwak.deployment.management.ModelDeploymentStatus\x12\x13\n\x0b\x64\x65ployed_by\x18\x03 \x01(\t\x12\x1b\n\x13\x66\x61ilure_reason_code\x18\x04 \x01(\t\x12\x17\n\x0f\x66\x61ilure_message\x18\x05 \x01(\t\x12\x19\n\x11technical_details\x18\x06 \x01(\t\x12\x38\n\x14\x64\x65ployment_timestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0e\x65nvironment_id\x18\x08 \x01(\t\x12\x16\n\x0evariation_name\x18\t \x01(\t\x12\x1f\n\x17variation_protect_state\x18\n \x01(\x08\x12\x15\n\rdeployment_id\x18\x0b \x01(\tB\x12\n\x10image_identifier\"\xd7\x02\n\x1eKubernetesModelDeploymentState\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x41\n\x06status\x18\x03 \x01(\x0e\x32\x31.qwak.deployment.management.ModelDeploymentStatus\x12\x41\n\x0estatus_details\x18\x04 \x01(\x0b\x32).qwak.deployment.management.StatusDetails\x12\x16\n\x0evariation_name\x18\x05 \x01(\t\x12\x15\n\rdeployment_id\x18\x06 \x01(\t\x12\x12\n\nmodel_uuid\x18\x07 \x01(\t\x12\x43\n\nmanaged_by\x18\x08 \x01(\x0e\x32/.qwak.deployment.management.DeploymentManagedBy\"\x9e\x02\n\rStatusDetails\x12R\n\x16pending_status_details\x18\x01 \x01(\x0b\x32\x30.qwak.deployment.management.PendingStatusDetailsH\x00\x12U\n\x16success_status_details\x18\x02 \x01(\x0b\x32\x33.qwak.deployment.management.SuccessfulStatusDetailsH\x00\x12P\n\x15\x66\x61iled_status_details\x18\x03 \x01(\x0b\x32/.qwak.deployment.management.FailedStatusDetailsH\x00\x42\x10\n\x0estatus_details\"\x9c\x01\n\x14PendingStatusDetails\x12\x41\n\x0cold_instance\x18\x01 \x01(\x0b\x32+.qwak.deployment.management.InstanceDetails\x12\x41\n\x0cnew_instance\x18\x02 \x01(\x0b\x32+.qwak.deployment.management.InstanceDetails\"`\n\x17SuccessfulStatusDetails\x12\x45\n\x10running_instance\x18\x01 \x01(\x0b\x32+.qwak.deployment.management.InstanceDetails\"\xe3\x01\n\x13\x46\x61iledStatusDetails\x12\x43\n\x0f\x66\x61ilure_details\x18\x01 \x01(\x0b\x32*.qwak.deployment.management.FailureDetails\x12\x41\n\x0cold_instance\x18\x02 \x01(\x0b\x32+.qwak.deployment.management.InstanceDetails\x12\x44\n\x0f\x66\x61iled_instance\x18\x03 \x01(\x0b\x32+.qwak.deployment.management.InstanceDetails\"\x91\x01\n\x0e\x46\x61ilureDetails\x12_\n\x1e\x64\x65ployment_failure_reason_code\x18\x01 \x01(\x0e\x32\x37.qwak.deployment.management.DeploymentFailureReasonCode\x12\x1e\n\x16\x66\x61ilure_reason_details\x18\x02 \x01(\t\"\x8f\x01\n\x0fInstanceDetails\x12\x15\n\rdeployment_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\x12\x1a\n\x12\x61vailable_replicas\x18\x03 \x01(\x05\x12\x37\n\x04pods\x18\x04 \x03(\x0e\x32).qwak.deployment.management.ModelPodPhase\"a\n\x17\x44\x65ploymentPhasesDetails\x12\x46\n\x11\x64\x65ployment_phases\x18\x01 \x03(\x0b\x32+.qwak.deployment.management.DeploymentPhase\"\xd7\x02\n\x0f\x44\x65ploymentPhase\x12N\n\x15\x64\x65ployment_phase_type\x18\x01 \x01(\x0e\x32/.qwak.deployment.management.DeploymentPhaseType\x12R\n\x17\x64\x65ployment_phase_status\x18\x02 \x01(\x0e\x32\x31.qwak.deployment.management.DeploymentPhaseStatus\x12!\n\x19phase_duration_in_seconds\x18\x03 \x01(\x05\x12.\n\nstarted_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10last_modified_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0f\x64isplay_message\x18\x06 \x01(\t\"\x88\x01\n\tVariation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x03 \x01(\t\x12:\n\x07traffic\x18\x02 \x01(\x0b\x32\'.qwak.deployment.management.TrafficSpecH\x00\x12\x11\n\tprotected\x18\x04 \x01(\x08\x42\x06\n\x04spec\"4\n\x0bTrafficSpec\x12\x12\n\npercentage\x18\x01 \x01(\x05\x12\x11\n\tis_shadow\x18\x02 \x01(\x08\"]\n\x18\x46utureDeploymentSettings\x12\x41\n\x0etraffic_config\x18\x01 \x01(\x0b\x32).qwak.deployment.management.TrafficConfig\"\xae\x02\n\x1c\x45nvironmentDeploymentMessage\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x12\n\x08\x62uild_id\x18\x03 \x01(\tH\x00\x12`\n\x1eqwak_model_registry_identifier\x18\x06 \x01(\x0b\x32\x36.qwak.deployment.management.QwakModeRegistryIdentifierH\x00\x12\x43\n\x0fhosting_service\x18\x04 \x01(\x0b\x32*.qwak.deployment.management.HostingService\x12\x16\n\nmodel_uuid\x18\x05 \x01(\tB\x02\x18\x01\x42\x12\n\x10image_identifier\"\x92\x01\n\"EnvironmentDeploymentResultMessage\x12\x1b\n\x13\x64\x65ployment_named_id\x18\x01 \x01(\t\x12\x41\n\x06status\x18\x02 \x01(\x0e\x32\x31.qwak.deployment.management.ModelDeploymentStatus\x12\x0c\n\x04info\x18\x03 \x01(\t\"\x90\x02\n\x1e\x45nvironmentUndeploymentMessage\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12V\n\x14hosting_service_type\x18\x03 \x01(\x0e\x32\x38.qwak.deployment.management.DeploymentHostingServiceType\x12\x41\n\x0etraffic_config\x18\x04 \x01(\x0b\x32).qwak.deployment.management.TrafficConfig\x12\x16\n\x0evariation_name\x18\x05 \x01(\t\x12\x12\n\nmodel_uuid\x18\x06 \x01(\t\"w\n$EnvironmentUndeploymentResultMessage\x12\x41\n\x06status\x18\x01 \x01(\x0e\x32\x31.qwak.deployment.management.ModelDeploymentStatus\x12\x0c\n\x04info\x18\x02 \x01(\t\"\xd6\x01\n+EnvironmentRuntimeDeploymentSettingsMessage\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12R\n\x13\x64\x65ployment_settings\x18\x03 \x01(\x0b\x32\x35.qwak.deployment.management.RuntimeDeploymentSettings\x12\x16\n\x0evariation_name\x18\x04 \x01(\t\x12\x12\n\nmodel_uuid\x18\x05 \x01(\t\"G\n1EnvironmentRuntimeDeploymentSettingsResultMessage\x12\x12\n\nerror_info\x18\x01 \x01(\t\"4\n$EnvironmentApplyModelTrafficResponse\x12\x0c\n\x04info\x18\x01 \x01(\t\"\xce\x01\n#EnvironmentDeploymentDetailsMessage\x12J\n\x13\x64\x65ployments_details\x18\x01 \x03(\x0b\x32-.qwak.deployment.management.DeploymentDetails\x12?\n\x10\x61udiences_routes\x18\x02 \x03(\x0b\x32%.qwak.audience.v1.AudienceRoutesEntry\x12\x1a\n\x12\x66\x61llback_variation\x18\x03 \x01(\t\"g\n#EnvironmentDeploymentHistoryMessage\x12@\n\x0b\x64\x65ployments\x18\x01 \x03(\x0b\x32+.qwak.deployment.management.DeploymentBrief\"V\n\x19\x45nvironmentTrafficMessage\x12\x39\n\nvariations\x18\x01 \x03(\x0b\x32%.qwak.deployment.management.Variation\"\x9e\x02\n BuildDeploymentEnvironmentStatus\x12\x87\x01\n\x1f\x65nvironment_to_deployment_brief\x18\x01 \x03(\x0b\x32^.qwak.deployment.management.BuildDeploymentEnvironmentStatus.EnvironmentToDeploymentBriefEntry\x1ap\n!EnvironmentToDeploymentBriefEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.qwak.deployment.management.DeploymentBrief:\x02\x38\x01\"S\n\x15\x42uildDeploymentStatus\x12\x12\n\nbuild_uuid\x18\x01 \x01(\t\x12\x13\n\x0bis_deployed\x18\x02 \x01(\x08\x12\x11\n\tis_in_use\x18\x03 \x01(\x08\"]\n\x1d\x43\x61ncelDeploymentRequestStatus\x12%\n\x1d\x63\x61ncel_requested_successfully\x18\x01 \x01(\x08\x12\x15\n\rerror_message\x18\x02 \x01(\t*\x85\x03\n\x15ModelDeploymentStatus\x12\x16\n\x12INVALID_DEPLOYMENT\x10\x00\x12\x19\n\x15INITIATING_DEPLOYMENT\x10\x01\x12 \n\x1c\x46\x41ILED_INITIATING_DEPLOYMENT\x10\x08\x12\x16\n\x12PENDING_DEPLOYMENT\x10\x02\x12\x19\n\x15SUCCESSFUL_DEPLOYMENT\x10\x03\x12\x15\n\x11\x46\x41ILED_DEPLOYMENT\x10\x04\x12\x1b\n\x17INITIATING_UNDEPLOYMENT\x10\t\x12\x18\n\x14PENDING_UNDEPLOYMENT\x10\n\x12\x1b\n\x17SUCCESSFUL_UNDEPLOYMENT\x10\x05\x12\x17\n\x13\x46\x41ILED_UNDEPLOYMENT\x10\x06\x12\t\n\x05UNSET\x10\x07\x12\x19\n\x15\x41LL_BUILDS_UNDEPLOYED\x10\x0b\x12\x18\n\x14\x43\x41NCELLED_DEPLOYMENT\x10\x0c\x12 \n\x1cINITIATING_CANCEL_DEPLOYMENT\x10\r*O\n\x1c\x44\x65ploymentHostingServiceType\x12\x0b\n\x07INVALID\x10\x00\x12\r\n\tSAGEMAKER\x10\x01\x12\x13\n\x0fKUBE_DEPLOYMENT\x10\x02*F\n\x12KubeDeploymentType\x12\r\n\tUNDEFINED\x10\x00\x12\n\n\x06ONLINE\x10\x01\x12\n\n\x06STREAM\x10\x02\x12\t\n\x05\x42\x41TCH\x10\x03*{\n\x07GpuType\x12\x0f\n\x0bINVALID_GPU\x10\x00\x12\x0e\n\nNVIDIA_K80\x10\x01\x12\x0f\n\x0bNVIDIA_V100\x10\x02\x12\x0f\n\x0bNVIDIA_A100\x10\x03\x12\r\n\tNVIDIA_T4\x10\x04\x12\x0f\n\x0bNVIDIA_A10G\x10\x05\x12\r\n\tNVIDIA_L4\x10\x06*+\n\nMemoryUnit\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03MIB\x10\x01\x12\x07\n\x03GIB\x10\x02*\x83\x01\n\x13\x44\x65ploymentManagedBy\x12!\n\x1d\x44\x45PLOYMENT_MANAGED_BY_INVALID\x10\x00\x12&\n\"DEPLOYMENT_MANAGED_BY_KUBE_CAPTAIN\x10\x01\x12!\n\x1d\x44\x45PLOYMENT_MANAGED_BY_ADMIRAL\x10\x02*\x93\x02\n\x1b\x44\x65ploymentFailureReasonCode\x12\x18\n\x14INVALID_FAILURE_CODE\x10\x00\x12\x12\n\x0eUNKNOWN_REASON\x10\x01\x12\x1e\n\x1aNO_REPLICA_SETS_PODS_FOUND\x10\x02\x12\x1d\n\x19MODEL_CONTAINER_NOT_FOUND\x10\x03\x12\x11\n\rUNSCHEDULABLE\x10\x04\x12\x1a\n\x16\x44OCKER_IMAGE_NOT_FOUND\x10\x05\x12\x19\n\x15MEMORY_LIMIT_EXCEEDED\x10\x06\x12\x0e\n\nCRASH_LOOP\x10\x07\x12-\n)CONTAINER_FAIL_TO_LOAD_FOR_UNKNOWN_REASON\x10\x08*\xb7\x01\n\rModelPodPhase\x12\x15\n\x11INVALID_POD_PHASE\x10\x00\x12)\n%MODEL_POD_PHASE_PROVISIONING_INSTANCE\x10\x01\x12!\n\x1dMODEL_POD_PHASE_PULLING_IMAGE\x10\x02\x12&\n\"MODEL_POD_PHASE_INITIALIZING_MODEL\x10\x03\x12\x19\n\x15MODEL_POD_PHASE_READY\x10\x04*\xac\x01\n\x13\x44\x65ploymentPhaseType\x12\x1c\n\x18INVALID_DEPLOYMENT_PHASE\x10\x00\x12*\n&DEPLOYMENT_PHASE_PROVISIONING_INSTANCE\x10\x01\x12\"\n\x1e\x44\x45PLOYMENT_PHASE_PULLING_IMAGE\x10\x02\x12\'\n#DEPLOYMENT_PHASE_INITIALIZING_MODEL\x10\x03*\xf5\x01\n\x15\x44\x65ploymentPhaseStatus\x12#\n\x1fINVALID_DEPLOYMENT_PHASE_STATUS\x10\x00\x12 \n\x1c\x44\x45PLOYMENT_PHASE_NOT_STARTED\x10\x01\x12\x1c\n\x18\x44\x45PLOYMENT_PHASE_STARTED\x10\x02\x12\x1d\n\x19\x44\x45PLOYMENT_PHASE_FINISHED\x10\x03\x12\x1d\n\x19\x44\x45PLOYMENT_PHASE_CANCELED\x10\x04\x12\x1b\n\x17\x44\x45PLOYMENT_PHASE_FAILED\x10\x05\x12\x1c\n\x18\x44\x45PLOYMENT_PHASE_ABORTED\x10\x06\x42\x45\n%com.qwak.ai.management.deployment.apiP\x01Z\x1aqwak/deployment;deploymentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.deployment.deployment_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.management.deployment.apiP\001Z\032qwak/deployment;deployment'
  _HOSTINGSERVICE.fields_by_name['sagemaker']._options = None
  _HOSTINGSERVICE.fields_by_name['sagemaker']._serialized_options = b'\030\001'
  _KUBEDEPLOYMENT_ENVIRONMENTVARIABLESENTRY._options = None
  _KUBEDEPLOYMENT_ENVIRONMENTVARIABLESENTRY._serialized_options = b'8\001'
  _KUBEDEPLOYMENT.fields_by_name['pod_count']._options = None
  _KUBEDEPLOYMENT.fields_by_name['pod_count']._serialized_options = b'\030\001'
  _TRAFFICCONFIG.fields_by_name['variations']._options = None
  _TRAFFICCONFIG.fields_by_name['variations']._serialized_options = b'\030\001'
  _DEPLOYMENTSIZE.fields_by_name['cpu']._options = None
  _DEPLOYMENTSIZE.fields_by_name['cpu']._serialized_options = b'\030\001'
  _DEPLOYMENTSIZE.fields_by_name['memory_amount']._options = None
  _DEPLOYMENTSIZE.fields_by_name['memory_amount']._serialized_options = b'\030\001'
  _DEPLOYMENTSIZE.fields_by_name['memory_units']._options = None
  _DEPLOYMENTSIZE.fields_by_name['memory_units']._serialized_options = b'\030\001'
  _DEPLOYMENTSIZE.fields_by_name['gpu_resources']._options = None
  _DEPLOYMENTSIZE.fields_by_name['gpu_resources']._serialized_options = b'\030\001'
  _DEPLOYMENTDETAILS_ENVIRONMENTVARIABLESENTRY._options = None
  _DEPLOYMENTDETAILS_ENVIRONMENTVARIABLESENTRY._serialized_options = b'8\001'
  _KUBERNETESMODELDEPLOYMENTSTATE.fields_by_name['branch_id']._options = None
  _KUBERNETESMODELDEPLOYMENTSTATE.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _ENVIRONMENTDEPLOYMENTMESSAGE.fields_by_name['branch_id']._options = None
  _ENVIRONMENTDEPLOYMENTMESSAGE.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _ENVIRONMENTDEPLOYMENTMESSAGE.fields_by_name['model_uuid']._options = None
  _ENVIRONMENTDEPLOYMENTMESSAGE.fields_by_name['model_uuid']._serialized_options = b'\030\001'
  _ENVIRONMENTUNDEPLOYMENTMESSAGE.fields_by_name['branch_id']._options = None
  _ENVIRONMENTUNDEPLOYMENTMESSAGE.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _ENVIRONMENTRUNTIMEDEPLOYMENTSETTINGSMESSAGE.fields_by_name['branch_id']._options = None
  _ENVIRONMENTRUNTIMEDEPLOYMENTSETTINGSMESSAGE.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _BUILDDEPLOYMENTENVIRONMENTSTATUS_ENVIRONMENTTODEPLOYMENTBRIEFENTRY._options = None
  _BUILDDEPLOYMENTENVIRONMENTSTATUS_ENVIRONMENTTODEPLOYMENTBRIEFENTRY._serialized_options = b'8\001'
  _globals['_MODELDEPLOYMENTSTATUS']._serialized_start=9466
  _globals['_MODELDEPLOYMENTSTATUS']._serialized_end=9855
  _globals['_DEPLOYMENTHOSTINGSERVICETYPE']._serialized_start=9857
  _globals['_DEPLOYMENTHOSTINGSERVICETYPE']._serialized_end=9936
  _globals['_KUBEDEPLOYMENTTYPE']._serialized_start=9938
  _globals['_KUBEDEPLOYMENTTYPE']._serialized_end=10008
  _globals['_GPUTYPE']._serialized_start=10010
  _globals['_GPUTYPE']._serialized_end=10133
  _globals['_MEMORYUNIT']._serialized_start=10135
  _globals['_MEMORYUNIT']._serialized_end=10178
  _globals['_DEPLOYMENTMANAGEDBY']._serialized_start=10181
  _globals['_DEPLOYMENTMANAGEDBY']._serialized_end=10312
  _globals['_DEPLOYMENTFAILUREREASONCODE']._serialized_start=10315
  _globals['_DEPLOYMENTFAILUREREASONCODE']._serialized_end=10590
  _globals['_MODELPODPHASE']._serialized_start=10593
  _globals['_MODELPODPHASE']._serialized_end=10776
  _globals['_DEPLOYMENTPHASETYPE']._serialized_start=10779
  _globals['_DEPLOYMENTPHASETYPE']._serialized_end=10951
  _globals['_DEPLOYMENTPHASESTATUS']._serialized_start=10954
  _globals['_DEPLOYMENTPHASESTATUS']._serialized_end=11199
  _globals['_QWAKMODEREGISTRYIDENTIFIER']._serialized_start=252
  _globals['_QWAKMODEREGISTRYIDENTIFIER']._serialized_end=292
  _globals['_HOSTINGSERVICE']._serialized_start=295
  _globals['_HOSTINGSERVICE']._serialized_end=453
  _globals['_KUBEDEPLOYMENT']._serialized_start=456
  _globals['_KUBEDEPLOYMENT']._serialized_end=967
  _globals['_KUBEDEPLOYMENT_ENVIRONMENTVARIABLESENTRY']._serialized_start=908
  _globals['_KUBEDEPLOYMENT_ENVIRONMENTVARIABLESENTRY']._serialized_end=967
  _globals['_SERVINGSTRATEGY']._serialized_start=970
  _globals['_SERVINGSTRATEGY']._serialized_end=1202
  _globals['_REALTIMECONFIG']._serialized_start=1205
  _globals['_REALTIMECONFIG']._serialized_end=1358
  _globals['_TRAFFICCONFIG']._serialized_start=1361
  _globals['_TRAFFICCONFIG']._serialized_end=1614
  _globals['_STREAMCONFIG']._serialized_start=1616
  _globals['_STREAMCONFIG']._serialized_end=1686
  _globals['_BATCHCONFIG']._serialized_start=1688
  _globals['_BATCHCONFIG']._serialized_end=1701
  _globals['_KAFKACONFIG']._serialized_start=1704
  _globals['_KAFKACONFIG']._serialized_end=2391
  _globals['_KAFKACONFIG_CONSUMER']._serialized_start=1873
  _globals['_KAFKACONFIG_CONSUMER']._serialized_end=2154
  _globals['_KAFKACONFIG_CONSUMER_AUTOOFFSETTYPE']._serialized_start=2099
  _globals['_KAFKACONFIG_CONSUMER_AUTOOFFSETTYPE']._serialized_end=2154
  _globals['_KAFKACONFIG_PRODUCER']._serialized_start=2157
  _globals['_KAFKACONFIG_PRODUCER']._serialized_end=2391
  _globals['_KAFKACONFIG_PRODUCER_COMPRESSIONTYPE']._serialized_start=2302
  _globals['_KAFKACONFIG_PRODUCER_COMPRESSIONTYPE']._serialized_end=2391
  _globals['_SAGEMAKER']._serialized_start=2393
  _globals['_SAGEMAKER']._serialized_end=2451
  _globals['_DEPLOYMENTSIZE']._serialized_start=2454
  _globals['_DEPLOYMENTSIZE']._serialized_end=2776
  _globals['_GPURESOURCES']._serialized_start=2778
  _globals['_GPURESOURCES']._serialized_end=2867
  _globals['_ADVANCEDDEPLOYMENTOPTIONS']._serialized_start=2870
  _globals['_ADVANCEDDEPLOYMENTOPTIONS']._serialized_end=3179
  _globals['_DEPLOYMENTDETAILS']._serialized_start=3182
  _globals['_DEPLOYMENTDETAILS']._serialized_end=4519
  _globals['_DEPLOYMENTDETAILS_ENVIRONMENTVARIABLESENTRY']._serialized_start=908
  _globals['_DEPLOYMENTDETAILS_ENVIRONMENTVARIABLESENTRY']._serialized_end=967
  _globals['_DEPLOYMENTFAILUREDETAILS']._serialized_start=4521
  _globals['_DEPLOYMENTFAILUREDETAILS']._serialized_end=4572
  _globals['_RUNTIMEDEPLOYMENTSETTINGS']._serialized_start=4575
  _globals['_RUNTIMEDEPLOYMENTSETTINGS']._serialized_end=4760
  _globals['_RUNTIMEDEPLOYMENTSETTINGS_LOGLEVEL']._serialized_start=4695
  _globals['_RUNTIMEDEPLOYMENTSETTINGS_LOGLEVEL']._serialized_end=4760
  _globals['_DEPLOYMENTBRIEF']._serialized_start=4763
  _globals['_DEPLOYMENTBRIEF']._serialized_end=5249
  _globals['_KUBERNETESMODELDEPLOYMENTSTATE']._serialized_start=5252
  _globals['_KUBERNETESMODELDEPLOYMENTSTATE']._serialized_end=5595
  _globals['_STATUSDETAILS']._serialized_start=5598
  _globals['_STATUSDETAILS']._serialized_end=5884
  _globals['_PENDINGSTATUSDETAILS']._serialized_start=5887
  _globals['_PENDINGSTATUSDETAILS']._serialized_end=6043
  _globals['_SUCCESSFULSTATUSDETAILS']._serialized_start=6045
  _globals['_SUCCESSFULSTATUSDETAILS']._serialized_end=6141
  _globals['_FAILEDSTATUSDETAILS']._serialized_start=6144
  _globals['_FAILEDSTATUSDETAILS']._serialized_end=6371
  _globals['_FAILUREDETAILS']._serialized_start=6374
  _globals['_FAILUREDETAILS']._serialized_end=6519
  _globals['_INSTANCEDETAILS']._serialized_start=6522
  _globals['_INSTANCEDETAILS']._serialized_end=6665
  _globals['_DEPLOYMENTPHASESDETAILS']._serialized_start=6667
  _globals['_DEPLOYMENTPHASESDETAILS']._serialized_end=6764
  _globals['_DEPLOYMENTPHASE']._serialized_start=6767
  _globals['_DEPLOYMENTPHASE']._serialized_end=7110
  _globals['_VARIATION']._serialized_start=7113
  _globals['_VARIATION']._serialized_end=7249
  _globals['_TRAFFICSPEC']._serialized_start=7251
  _globals['_TRAFFICSPEC']._serialized_end=7303
  _globals['_FUTUREDEPLOYMENTSETTINGS']._serialized_start=7305
  _globals['_FUTUREDEPLOYMENTSETTINGS']._serialized_end=7398
  _globals['_ENVIRONMENTDEPLOYMENTMESSAGE']._serialized_start=7401
  _globals['_ENVIRONMENTDEPLOYMENTMESSAGE']._serialized_end=7703
  _globals['_ENVIRONMENTDEPLOYMENTRESULTMESSAGE']._serialized_start=7706
  _globals['_ENVIRONMENTDEPLOYMENTRESULTMESSAGE']._serialized_end=7852
  _globals['_ENVIRONMENTUNDEPLOYMENTMESSAGE']._serialized_start=7855
  _globals['_ENVIRONMENTUNDEPLOYMENTMESSAGE']._serialized_end=8127
  _globals['_ENVIRONMENTUNDEPLOYMENTRESULTMESSAGE']._serialized_start=8129
  _globals['_ENVIRONMENTUNDEPLOYMENTRESULTMESSAGE']._serialized_end=8248
  _globals['_ENVIRONMENTRUNTIMEDEPLOYMENTSETTINGSMESSAGE']._serialized_start=8251
  _globals['_ENVIRONMENTRUNTIMEDEPLOYMENTSETTINGSMESSAGE']._serialized_end=8465
  _globals['_ENVIRONMENTRUNTIMEDEPLOYMENTSETTINGSRESULTMESSAGE']._serialized_start=8467
  _globals['_ENVIRONMENTRUNTIMEDEPLOYMENTSETTINGSRESULTMESSAGE']._serialized_end=8538
  _globals['_ENVIRONMENTAPPLYMODELTRAFFICRESPONSE']._serialized_start=8540
  _globals['_ENVIRONMENTAPPLYMODELTRAFFICRESPONSE']._serialized_end=8592
  _globals['_ENVIRONMENTDEPLOYMENTDETAILSMESSAGE']._serialized_start=8595
  _globals['_ENVIRONMENTDEPLOYMENTDETAILSMESSAGE']._serialized_end=8801
  _globals['_ENVIRONMENTDEPLOYMENTHISTORYMESSAGE']._serialized_start=8803
  _globals['_ENVIRONMENTDEPLOYMENTHISTORYMESSAGE']._serialized_end=8906
  _globals['_ENVIRONMENTTRAFFICMESSAGE']._serialized_start=8908
  _globals['_ENVIRONMENTTRAFFICMESSAGE']._serialized_end=8994
  _globals['_BUILDDEPLOYMENTENVIRONMENTSTATUS']._serialized_start=8997
  _globals['_BUILDDEPLOYMENTENVIRONMENTSTATUS']._serialized_end=9283
  _globals['_BUILDDEPLOYMENTENVIRONMENTSTATUS_ENVIRONMENTTODEPLOYMENTBRIEFENTRY']._serialized_start=9171
  _globals['_BUILDDEPLOYMENTENVIRONMENTSTATUS_ENVIRONMENTTODEPLOYMENTBRIEFENTRY']._serialized_end=9283
  _globals['_BUILDDEPLOYMENTSTATUS']._serialized_start=9285
  _globals['_BUILDDEPLOYMENTSTATUS']._serialized_end=9368
  _globals['_CANCELDEPLOYMENTREQUESTSTATUS']._serialized_start=9370
  _globals['_CANCELDEPLOYMENTREQUESTSTATUS']._serialized_end=9463
# @@protoc_insertion_point(module_scope)
