"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.administration.runtime_configuration.v0.creds.secret_pb2
import qwak.administration.runtime_configuration.v0.external.databricks.auth_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AzureAuthentication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AZURE_DATABRICKS_AUTH_FIELD_NUMBER: builtins.int
    @property
    def azure_databricks_auth(self) -> global___AzureDatabricksServiceAuthentication: ...
    def __init__(
        self,
        *,
        azure_databricks_auth: global___AzureDatabricksServiceAuthentication | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["azure_databricks_auth", b"azure_databricks_auth", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["azure_databricks_auth", b"azure_databricks_auth", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["azure_databricks_auth"] | None: ...

global___AzureAuthentication = AzureAuthentication

class AzureDatabricksServiceAuthentication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DB_AUTH_FIELD_NUMBER: builtins.int
    AZURE_BLOB_STORAGE_AUTH_FIELD_NUMBER: builtins.int
    @property
    def db_auth(self) -> qwak.administration.runtime_configuration.v0.external.databricks.auth_pb2.DatabricksAuth: ...
    @property
    def azure_blob_storage_auth(self) -> global___AzureBlobStorageAuth: ...
    def __init__(
        self,
        *,
        db_auth: qwak.administration.runtime_configuration.v0.external.databricks.auth_pb2.DatabricksAuth | None = ...,
        azure_blob_storage_auth: global___AzureBlobStorageAuth | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["azure_blob_storage_auth", b"azure_blob_storage_auth", "db_auth", b"db_auth"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["azure_blob_storage_auth", b"azure_blob_storage_auth", "db_auth", b"db_auth"]) -> None: ...

global___AzureDatabricksServiceAuthentication = AzureDatabricksServiceAuthentication

class AzureBlobStorageAuth(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SAS_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def sas_token(self) -> global___AzureSASToken: ...
    def __init__(
        self,
        *,
        sas_token: global___AzureSASToken | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth_type", b"auth_type", "sas_token", b"sas_token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_type", b"auth_type", "sas_token", b"sas_token"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth_type", b"auth_type"]) -> typing_extensions.Literal["sas_token"] | None: ...

global___AzureBlobStorageAuth = AzureBlobStorageAuth

class AzureSASToken(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_FIELD_NUMBER: builtins.int
    @property
    def secret(self) -> qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef: ...
    def __init__(
        self,
        *,
        secret: qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["location", b"location", "secret", b"secret"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "secret", b"secret"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["location", b"location"]) -> typing_extensions.Literal["secret"] | None: ...

global___AzureSASToken = AzureSASToken
