# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/automation/v1/automation_execution.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-qwak/automation/v1/automation_execution.proto\x12\x12qwak.automation.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"w\n\x1a\x41utomationExecutionMessage\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\x12\x43\n\x0brun_details\x18\x02 \x01(\x0b\x32..qwak.automation.v1.ExecutionRunDetailsMessage\"\xa7\x02\n\x1a\x45xecutionRunDetailsMessage\x12.\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rerror_details\x18\x03 \x01(\t\x12:\n\x06status\x18\x04 \x01(\x0e\x32*.qwak.automation.v1.ExecutionStatusMessage\x12\x0c\n\x04task\x18\x05 \x01(\t\x12\x14\n\x0c\x66inish_cause\x18\x06 \x01(\t\x12\x34\n\x10last_update_date\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"i\n\tDateRange\x12.\n\nstart_date\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp*P\n\x16\x45xecutionStatusMessage\x12\r\n\tUNDEFINED\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\x0e\n\nSUCCESSFUL\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x42!\n\x1d\x63om.qwak.ai.automation.api.v1P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.automation.v1.automation_execution_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.ai.automation.api.v1P\001'
  _globals['_EXECUTIONSTATUSMESSAGE']._serialized_start=628
  _globals['_EXECUTIONSTATUSMESSAGE']._serialized_end=708
  _globals['_AUTOMATIONEXECUTIONMESSAGE']._serialized_start=102
  _globals['_AUTOMATIONEXECUTIONMESSAGE']._serialized_end=221
  _globals['_EXECUTIONRUNDETAILSMESSAGE']._serialized_start=224
  _globals['_EXECUTIONRUNDETAILSMESSAGE']._serialized_end=519
  _globals['_DATERANGE']._serialized_start=521
  _globals['_DATERANGE']._serialized_end=626
# @@protoc_insertion_point(module_scope)
